@@ -385,6 +385,11 @@ spmtree = function(formula,
 
 #    if not missing, coerce types input to R "data.frame" object
     if(missing(types) == FALSE){
+        
+        if(!all(types %in% c("ordinal", "nominal", "binary",
+                             "response", "C", "treatment"))){
+            stop("The type input is invalid.")
+        }
 
         types = as.data.frame(types)
 
@@ -407,6 +412,9 @@ spmtree = function(formula,
 
 #    response variable should always be (first) in lhs
     Y = data[, form_lhs[1]]
+    if(!class(Y) %in% c("numeric", "integer")){
+        stop("Response Y must be numerical.")
+    }
 
 #    get censoring variable if applicable
     if(length(form_lhs) == 1){
@@ -416,11 +424,20 @@ spmtree = function(formula,
 
     if(length(form_lhs) == 2){
         C = data[, form_lhs[2]]
+        if(!class(C) %in% c("numeric", "integer", "logical")){
+            stop("C must be integers.")
+        }
+        if(!all(unique(C) %in% c(0, 1))){
+            stop("C must be 0 or 1.")
+        }
         surv = 1
     }
 
 #    treatment variable should always be first in rhs
     treatment = data[, form_rhs[1]]
+    if(!class(treatment) %in% c("numeric", "integer")){
+        stop("Treatment must be integers.")
+    }
 
 #    determine appropriate method from data
     ntrts = nlevels(as.factor(treatment))
@@ -434,6 +451,10 @@ spmtree = function(formula,
     }
 
     if(ntrts == 2){
+        
+        if(!all(unique(treatment) %in% c(0, 1))){
+            stop("Treatment must be 0 or 1 for two treatment groups.")
+        }
 
         if(surv == 0){
 
@@ -445,6 +466,10 @@ spmtree = function(formula,
         }
 
     }else if(ntrts > 2){
+        
+        if(!all(unique(treatment) %in% rep(1:ntrts))){
+            stop("Treatment must be 1 to ntrts for more than two treatment groups.")
+        }
 
         if(surv == 0){
 
@@ -470,7 +495,6 @@ spmtree = function(formula,
 
         X = data.frame(data[, -exclude])
         types = types[, -exclude]
-
     }else{
 
         include = which(colnames(data) %in% form_rhs[-1])
@@ -483,7 +507,11 @@ spmtree = function(formula,
     n = nrow(X)
     nc = ncol(X)
     if(nc == 1){
-        names(X) = names(data)[-exclude]
+        if( form_rhs[2] == "." ){
+            names(X) = names(data)[-exclude]
+        }else{
+            names(X) = names(data)[include]
+        }
     }
 
 #    prepare types
@@ -495,7 +523,15 @@ spmtree = function(formula,
         message("Note that all candidate split variables are assumed to be ordinal.")
 
     }else{
-
+        if(nc == 1){
+            types = data.frame(types)
+            if( form_rhs[2] == "." ){
+                names(types) = names(data)[-exclude]
+            }else{
+                names(types) = names(data)[include]
+            }
+            rownames(types) = "types"
+        }
         lll = ncol(types)
         for (i in 1:lll){
             if(types[i] == "binary") types[i] = 1
@@ -504,12 +540,53 @@ spmtree = function(formula,
         }
     }
 
+    ifbinary = any(types == 1)
+    if(ifbinary == TRUE){
+        ibin = which(types == 1)
+        if(length(ibin) == 1){
+            if(!class(data[, ibin]) %in% c("numeric", "integer")){
+                stop("Binary variables must be integers.")
+            }
+            if(!all(unique(data[, ibin]) %in% c(0, 1))){
+                stop("Binary varialbes must be 0 or 1.")
+            }
+        }else{
+            if(!all(apply(data[, ibin], 2, class) %in% c("numeric", "integer"))){
+                stop("Binary variables must be integers.")
+            }
+            if(!all(apply(data[, ibin], 2, unique) %in% c(0, 1))){
+                stop("Binary varialbes must be 0 or 1.")
+            }
+        }
+    }
+    
+    ifordinal = any(types == 2)
+    if(ifordinal == TRUE){
+        iord = which(types == 2)
+        if(length(iord) == 1){
+            if(!class(data[, iord]) %in% c("numeric", "integer")){
+                stop("Ordinal variables must be numerical.")
+            }
+        }else{
+            if(!all(apply(data[, iord], 2, class) %in% c("numeric", "integer"))){
+                stop("Ordinal variables must be numerical.")
+            }
+        }
+    }
+    
 #    create array of number of categories for nominal variables
     ifnominal = any(types == 3)
     if(ifnominal == TRUE){
 
         inom = which(types == 3)
         for(i in 1:length(inom)){
+            if(!class(X[, inom[i]]) %in% c("numeric", "integer")){
+                stop("Nominal variables must be integers.")
+            }
+            ncats = length(unique(X[, inom[i]]))
+            if(!all(unique(X[, inom[i]]) %in% rep(1:ncats))){
+                stop("Nominal must be 1 to ncats.")
+            }
             X[, inom[i]] = factor(X[, inom[i]])
             data[, colnames(X)[inom[i]]] = X[, inom[i]]
         }
